@@ -1442,7 +1442,7 @@ image_viewer_scroll_event (GtkWidget        *widget,
 GType
 image_viewer_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
