@@ -117,6 +117,7 @@ typedef struct {
 	char                *local_folder;
 
 	GthImporterOp        current_op;
+	gboolean             async_operation;
 	gboolean             interrupted;
 	gboolean             error;
 	float                target;
@@ -522,6 +523,9 @@ async_operation_step (gpointer callback_data)
 	g_mutex_unlock (aodata->data->yes_or_no);
 
 	if ((aodata->scan == NULL) || interrupted) {
+		g_mutex_lock (aodata->data->yes_or_no);
+		aodata->data->async_operation = FALSE;
+		g_mutex_unlock (aodata->data->yes_or_no);
 		if (aodata->done_func != NULL)
 			(*aodata->done_func) (aodata, aodata->data);
 		g_free (aodata);
@@ -554,6 +558,7 @@ async_operation_start (AsyncOperationData *aodata)
 		(*aodata->init_func) (aodata, aodata->data);
 
 	g_mutex_lock (aodata->data->yes_or_no);
+	aodata->data->async_operation = TRUE;
 	aodata->data->interrupted = FALSE;
 	g_mutex_unlock (aodata->data->yes_or_no);
 
@@ -755,11 +760,13 @@ load_images_preview (DialogData *data)
 					  GTK_ICON_SIZE_BUTTON);
 		gtk_label_set_text (GTK_LABEL (data->progress_info_label), _("No images found"));
 		gtk_widget_show (data->progress_info_box);
+		gtk_window_set_resizable (GTK_WINDOW (data->dialog), FALSE);
 		return;
 
 	} else {
 		gtk_widget_show (data->import_preview_box);
 		gtk_widget_hide (data->progress_info_box);
+		gtk_window_set_resizable (GTK_WINDOW (data->dialog), TRUE);
 	}
 
 	aodata = async_operation_new (file_list,
@@ -784,6 +791,7 @@ set_camera_model (DialogData *data,
 		gtk_widget_hide (data->import_preview_box);
 		gtk_label_set_text (GTK_LABEL (data->camera_model_label), _("No camera detected"));
 		gtk_image_set_from_pixbuf (GTK_IMAGE (data->progress_camera_image), data->no_camera_pixbuf);
+		gtk_window_set_resizable (GTK_WINDOW (data->dialog), FALSE);
 		return;
 	}
 
@@ -1247,6 +1255,25 @@ save_images__done (AsyncOperationData *aodata,
 }
 
 
+static void
+cancel_clicked_cb (GtkButton  *button,
+		   DialogData *data)
+{
+	gboolean async_operation;
+
+	g_mutex_lock (data->yes_or_no);
+	async_operation = data->async_operation;
+	g_mutex_unlock (data->yes_or_no);
+
+	if (async_operation) {
+		g_mutex_lock (data->yes_or_no);
+		data->interrupted = TRUE;
+		g_mutex_unlock (data->yes_or_no);
+	} else
+		gtk_widget_destroy (data->dialog);
+}
+
+
 static void
 ok_clicked_cb (GtkButton  *button,
 	       DialogData *data)
@@ -1576,6 +1603,7 @@ dlg_photo_importer (GThumbWindow *window)
 	gtk_container_add (GTK_CONTAINER (data->import_preview_scrolledwindow), data->image_list);
 
 	gtk_widget_hide (data->import_preview_box);
+	gtk_window_set_resizable (GTK_WINDOW (data->dialog), FALSE);
 
 	/* Set widgets data. */
 
@@ -1633,10 +1661,10 @@ dlg_photo_importer (GThumbWindow *window)
 			  "clicked",
 			  G_CALLBACK (ok_clicked_cb),
 			  data);
-	g_signal_connect_swapped (G_OBJECT (btn_cancel), 
-				  "clicked",
-				  G_CALLBACK (gtk_widget_destroy),
-				  G_OBJECT (data->dialog));
+	g_signal_connect (G_OBJECT (btn_cancel), 
+			  "clicked",
+			  G_CALLBACK (cancel_clicked_cb),
+			  data);
 	g_signal_connect (G_OBJECT (data->select_model_button), 
 			  "clicked",
 			  G_CALLBACK (dlg_select_camera_model_cb),
